import type { Express } from "express";
import { createServer, type Server } from "http";
import { storage } from "./storage";

// Mock data for the crypto API endpoints
const cryptoData = {
  prices: [
    { symbol: "BTC", price: 36245.18, change: 3.42 },
    { symbol: "ETH", price: 1985.65, change: 2.18 },
    { symbol: "BNB", price: 245.32, change: 1.25 },
    { symbol: "ADA", price: 0.384, change: -2.45 },
    { symbol: "SOL", price: 42.87, change: 4.62 }
  ],
  trending: [
    { symbol: "SOL", change: 4.62 },
    { symbol: "BTC", change: 3.42 },
    { symbol: "ETH", change: 2.18 },
    { symbol: "BNB", change: 1.25 },
    { symbol: "ADA", change: -2.45 }
  ],
  signals: [
    { pair: "BTC/USDT", signal: "BUY", confidence: 87 },
    { pair: "ETH/USDT", signal: "BUY", confidence: 82 },
    { pair: "SOL/USDT", signal: "HOLD", confidence: 65 },
    { pair: "ADA/USDT", signal: "SELL", confidence: 78 }
  ]
};

export async function registerRoutes(app: Express): Promise<Server> {
  // API routes
  app.get("/api/crypto/prices", (req, res) => {
    res.json(cryptoData.prices);
  });

  app.get("/api/crypto/trending", (req, res) => {
    res.json(cryptoData.trending);
  });

  app.get("/api/crypto/signals", (req, res) => {
    res.json(cryptoData.signals);
  });

  // Subscribe to newsletter endpoint
  app.post("/api/subscribe", (req, res) => {
    const { email } = req.body;
    
    if (!email || !/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
      return res.status(400).json({ success: false, message: "Invalid email address" });
    }
    
    // In a real app, you'd store this in a database
    return res.json({ 
      success: true, 
      message: "Successfully subscribed to newsletter" 
    });
  });

  // Contact form endpoint
  app.post("/api/contact", (req, res) => {
    const { name, email, message } = req.body;
    
    if (!name || !email || !message) {
      return res.status(400).json({ 
        success: false, 
        message: "All fields are required" 
      });
    }
    
    if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
      return res.status(400).json({ 
        success: false, 
        message: "Invalid email address" 
      });
    }
    
    // In a real app, you'd store this in a database and send an email
    return res.json({ 
      success: true, 
      message: "Message received. We'll get back to you soon!" 
    });
  });

  const httpServer = createServer(app);
  return httpServer;
}
